@@ -11,12 +11,15 @@ from starlette.routing import BaseRoute, Mount
 from starlette.routing import Router as StarletteRouter
 
 from xpresso.routing.pathitem import Path
+from xpresso.routing.router import Router as XpressoRouter
 from xpresso.routing.websockets import WebSocketRoute
 
+Router = typing.Union[XpressoRouter, StarletteRouter]
+
 
 class App(Protocol):
     @property
-    def router(self) -> StarletteRouter:
+    def router(self) -> XpressoRouter:
         ...
 
 
@@ -26,21 +29,21 @@ AppType = typing.TypeVar("AppType", bound=App)
 @dataclass(frozen=True)
 class VisitedRoute(typing.Generic[AppType]):
     path: str
-    nodes: typing.List[typing.Union[StarletteRouter, AppType]]
+    nodes: typing.List[typing.Union[Router, AppType]]
     route: BaseRoute
 
 
 def visit_routes(
     app_type: typing.Type[AppType],
-    router: StarletteRouter,
-    nodes: typing.List[typing.Union[StarletteRouter, AppType]],
+    router: Router,
+    nodes: typing.List[typing.Union[Router, AppType]],
     path: str,
 ) -> typing.Generator[VisitedRoute[AppType], None, None]:
     for route in typing.cast(typing.Iterable[BaseRoute], router.routes):  # type: ignore  # for Pylance
         if isinstance(route, Mount):
             app: typing.Any = route.app
             mount_path: str = route.path  # type: ignore  # for Pylance
-            if isinstance(app, StarletteRouter):
+            if isinstance(app, (StarletteRouter, XpressoRouter)):
                 yield VisitedRoute(
                     path=path,
                     nodes=nodes + [app],
